@@ -102,18 +102,18 @@ static int    *sort1, *sort2;
 static double *tmean;
 static int    ptype, pdiag;
 static double *ipen, *upen, logpen;
-static Sint   *zflag;
+static int   *zflag;
 
 static double **cmatrix(double *, int, int);
 
-void agfit5a(Sint *nusedx, Sint *nvarx, double *yy, 
+void agfit5a(int *nusedx, int *nvarx, double *yy, 
 	       double *covar2, double *offset2,
 	       double *weights2, 
-	       Sint   *strata,  Sint   *sort,
+	       int   *strata,  int   *sort,
 	       double *means, double *beta, double *u, 
 	       double *loglik, 
-	       Sint *methodx, Sint *ptype2, Sint *pdiag2,
-	       Sint *nfrail,  Sint *frail2,
+	       int *methodx, int *ptype2, int *pdiag2,
+	       int *nfrail,  int *frail2,
                void *fexpr1, void *fexpr2, void *rho) {
 
     int i,j,k, person;
@@ -180,8 +180,8 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
     if (pdiag==0)  upen = Calloc(2*i, double);
     else           upen = Calloc(i+j, double);
     ipen = upen + i;
-    if (ptype>1)  zflag = Calloc(nvar, Sint);
-    else          zflag = Calloc(2, Sint);
+    if (ptype>1)  zflag = Calloc(nvar, int);
+    else          zflag = Calloc(2, int);
 
     if (nf>0) {
 	frail = Calloc(nused, int);
@@ -311,11 +311,11 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
 ** This call is used for iteration
 */
 
-void agfit5b(Sint *maxiter, Sint *nusedx, Sint *nvarx, 
-	       Sint *strata, double *beta, double *u,
+void agfit5b(int *maxiter, int *nusedx, int *nvarx, 
+	       int *strata, double *beta, double *u,
 	       double *imat2,  double *jmat2, double *loglik, 
-	       Sint *flag,  double *eps, double *tolerch, Sint *methodx, 
-	       Sint *nfrail, double *fbeta, double *fdiag,
+	       int *flag,  double *eps, double *tolerch, int *methodx, 
+	       int *nfrail, double *fbeta, double *fdiag,
                void *fexpr1, void *fexpr2, void *rho)
 {
     int i,j,k, person;
@@ -687,7 +687,7 @@ static void cmatrix_free(double **data) {
     Free(data);
     }
 
-void agfit5c(Sint *nvar) {
+void agfit5c(int *nvar) {
     /*
     ** Free up the extra memory
     */
